@@ -20,10 +20,11 @@ import (
 	"fmt"
 	"io"
 
-	monv1 "github.com/coreos/prometheus-operator/pkg/apis/monitoring/v1"
 	configv1 "github.com/openshift/api/config/v1"
+	monv1 "github.com/prometheus-operator/prometheus-operator/pkg/apis/monitoring/v1"
 	v1 "k8s.io/api/core/v1"
 	k8syaml "k8s.io/apimachinery/pkg/util/yaml"
+	"k8s.io/klog/v2"
 )
 
 const (
@@ -52,11 +53,8 @@ type ClusterMonitoringConfiguration struct {
 	K8sPrometheusAdapter     *K8sPrometheusAdapter        `json:"k8sPrometheusAdapter"`
 	ThanosQuerierConfig      *ThanosQuerierConfig         `json:"thanosQuerier"`
 	UserWorkloadEnabled      *bool                        `json:"enableUserWorkload"`
-	// TODO: Remove in 4.7 release.
-	PrometheusUserWorkloadConfig         *PrometheusK8sConfig      `json:"prometheusUserWorkload"`
-	PrometheusOperatorUserWorkloadConfig *PrometheusOperatorConfig `json:"prometheusOperatorUserWorkload"`
-	ThanosRulerConfig                    *ThanosRulerConfig        `json:"thanosRuler"`
-	UserWorkloadConfig                   *UserWorkloadConfig       `json:"techPreviewUserWorkload"`
+	// TODO: remove in 4.8, this is here to ensure we warn users that their config will not work.
+	UserWorkloadConfig *UserWorkloadConfig `json:"techPreviewUserWorkload"`
 }
 
 type Images struct {
@@ -64,7 +62,6 @@ type Images struct {
 	PromLabelProxy           string
 	PrometheusOperator       string
 	PrometheusConfigReloader string
-	ConfigmapReloader        string
 	Prometheus               string
 	Alertmanager             string
 	Grafana                  string
@@ -117,6 +114,7 @@ type ThanosRulerConfig struct {
 }
 
 type ThanosQuerierConfig struct {
+	LogLevel     string                   `json:"logLevel"`
 	NodeSelector map[string]string        `json:"nodeSelector"`
 	Tolerations  []v1.Toleration          `json:"tolerations"`
 	Resources    *v1.ResourceRequirements `json:"resources"`
@@ -207,21 +205,12 @@ func (c *Config) applyDefaults() {
 	if c.ClusterMonitoringConfiguration.PrometheusOperatorConfig == nil {
 		c.ClusterMonitoringConfiguration.PrometheusOperatorConfig = &PrometheusOperatorConfig{}
 	}
-	if c.ClusterMonitoringConfiguration.PrometheusOperatorUserWorkloadConfig == nil {
-		c.ClusterMonitoringConfiguration.PrometheusOperatorUserWorkloadConfig = &PrometheusOperatorConfig{}
-	}
 	if c.ClusterMonitoringConfiguration.PrometheusK8sConfig == nil {
 		c.ClusterMonitoringConfiguration.PrometheusK8sConfig = &PrometheusK8sConfig{}
 	}
 	if c.ClusterMonitoringConfiguration.PrometheusK8sConfig.Retention == "" {
 		c.ClusterMonitoringConfiguration.PrometheusK8sConfig.Retention = DefaultRetentionValue
 	}
-	if c.ClusterMonitoringConfiguration.PrometheusUserWorkloadConfig == nil {
-		c.ClusterMonitoringConfiguration.PrometheusUserWorkloadConfig = &PrometheusK8sConfig{}
-	}
-	if c.ClusterMonitoringConfiguration.PrometheusUserWorkloadConfig.Retention == "" {
-		c.ClusterMonitoringConfiguration.PrometheusUserWorkloadConfig.Retention = DefaultRetentionValue
-	}
 	if c.ClusterMonitoringConfiguration.AlertmanagerMainConfig == nil {
 		c.ClusterMonitoringConfiguration.AlertmanagerMainConfig = &AlertmanagerMainConfig{}
 	}
@@ -229,9 +218,6 @@ func (c *Config) applyDefaults() {
 		disable := false
 		c.ClusterMonitoringConfiguration.UserWorkloadEnabled = &disable
 	}
-	if c.ClusterMonitoringConfiguration.ThanosRulerConfig == nil {
-		c.ClusterMonitoringConfiguration.ThanosRulerConfig = &ThanosRulerConfig{}
-	}
 	if c.ClusterMonitoringConfiguration.ThanosQuerierConfig == nil {
 		c.ClusterMonitoringConfiguration.ThanosQuerierConfig = &ThanosQuerierConfig{}
 	}
@@ -266,7 +252,6 @@ func (c *Config) applyDefaults() {
 func (c *Config) SetImages(images map[string]string) {
 	c.Images.PrometheusOperator = images["prometheus-operator"]
 	c.Images.PrometheusConfigReloader = images["prometheus-config-reloader"]
-	c.Images.ConfigmapReloader = images["configmap-reloader"]
 	c.Images.Prometheus = images["prometheus"]
 	c.Images.Alertmanager = images["alertmanager"]
 	c.Images.Grafana = images["grafana"]
@@ -431,7 +416,7 @@ func NewDefaultUserWorkloadMonitoringConfig() *UserWorkloadConfiguration {
 }
 
 // IsUserWorkloadEnabled checks if user workload monitoring is
-// enabled on old or new configuration.
+// enabled. If old techPreview configuration exists, we warn user in logs.
 func (c *Config) IsUserWorkloadEnabled() bool {
 	if *c.ClusterMonitoringConfiguration.UserWorkloadEnabled == true {
 		return true
@@ -440,11 +425,12 @@ func (c *Config) IsUserWorkloadEnabled() bool {
 	return c.ClusterMonitoringConfiguration.UserWorkloadConfig.isEnabled()
 }
 
-// isEnabled returns the underlying value of the `Enabled` boolean pointer.
-// It defaults to false if the pointer is nil.
+// return false, as this configuration is techPreview
+// and depracted from 4.7 onwards.
+// Instead warn user in the logs.
 func (c *UserWorkloadConfig) isEnabled() bool {
-	if c.Enabled == nil {
-		return false
+	if c.Enabled != nil {
+		klog.Warning("DEPRECATED: Migrate to new user workload monitoring configuration, this tech preview was removed.")
 	}
-	return *c.Enabled
+	return false
 }
